// @flow
import React from "react";
import { isEqual } from "lodash";
import { ReactComponent as Se7enskyLogo } from "../assets/se7ensky-simple-svg.svg";

class Logo extends React.Component<*> {
	static defaultProps = {
		width: 82,
		height: 40,
		mobileWidth: 82,
		mobileHeight: 40,
		altText: "SE7ENSKY",
		className: ""
	};

	checkDisplayInterval = null;

	state = { display: "desktop" };

	shouldComponentUpdate(props, state) {
		return !isEqual(state, this.state);
	}

	componentDidMount() {
		this.checkDisplayInterval = setInterval(() => {
			this.setState({ display: window.outerWidth > 768 ? "desktop" : "mobile" });
		}, 500);
	}

	componentWillUnmount() {
		clearInterval(this.checkDisplayInterval);
	}

	render() {
		const { className, altText } = this.props;

		let style = {
			width: this.props.width,
			height: this.props.height,
			display: this.props.display,
			marginTop: 12
		};

		if (this.state.display !== "desktop") {
			style.width = this.props.mobileWidth;
			style.height = this.props.mobileHeight;
		}

		return (
			<Se7enskyLogo
				className={["se7ensky-logo", className].join(" ")}
				style={style}
				alt={altText}
			/>
		);
	}
}

export default Logo;
