// @flow
import React from "react";
import type { ElementPluginType } from "webiny-app-cms/types";
import { Tab } from "webiny-ui/Tabs";
import ImagesListImagesSettings from "webiny-app-cms/editor/plugins/elements/imagesList/ImagesListImagesSettings";
import { ReactComponent as ImageGalleryIcon } from "webiny-app-cms/editor/plugins/elements/imagesList/icons/round-photo_library-24px.svg";
import { ReactComponent as ImagesIcon } from "webiny-app-cms/admin/assets/round-photo_library-24px.svg";
import styled from "react-emotion";

import Carousel from "./components/Carousel";


export default () => {
	const PreviewBox = styled("div")({
		textAlign: "center",
		margin: "0 auto",
		width: 50,
		svg: {
			width: 50
		}
	});

	return [
		({
			name: "cms-element-images-carousel",
			type: "cms-element",
			toolbar: {
				title: "Image Carousel",
				group: "cms-element-group-basic",
				preview() {
					return (
						<PreviewBox>
							<ImageGalleryIcon />
						</PreviewBox>
					);
				}
			},
			settings: ["cms-element-settings-delete"],
			target: ["cms-element-row", "cms-element-column"],
			onCreate: "open-settings",
			create(options = {}) {
				return {
					type: "cms-element-images-carousel",
					data: {
						component: "cms-element-images-list-component-mosaic",
						settings: {
							margin: {
								desktop: { all: 0 },
								mobile: { all: 0 }
							},
							padding: {
								desktop: { all: 0 },
								mobile: { all: 0 }
							}
						}
					},
					...options
				};
			},
			render({ element }) {
				return <Carousel data={element.data} />;
			}
		}: ElementPluginType),
		{
			name: "cms-element-advanced-settings-images-carousel-filter",
			type: "cms-element-advanced-settings",
			element: "cms-element-images-carousel",
			render(props: Object) {
				return (
					<Tab icon={<ImagesIcon />} label="Images">
						<ImagesListImagesSettings {...props} filter />
					</Tab>
				);
			}
		},
	];
};
