import React from "react";
import styled from "react-emotion";
import Slider from "react-slick";

const Carousel = ({ data: { images } }) => {
	if (!images) return "You must select images to render your image carousel!";

	const settings = {
		arrows: false,
		dots: true
	};

	return (
		<CarouselStyles>
			<Slider {...settings}>
				{images.map(image => (
					<div className="slick-image" key={image.name} >
						<img className="slick-image-i" src={image.src} alt={image.name} />
					</div>
				))}
			</Slider>
		</CarouselStyles>
	);
};

const CarouselStyles = styled("div")`
	.slick-image {
		display: flex !important;
		justify-content: center;
		align-items: center;
		height: calc(100vh - 5.1vw);
		outline: none;
		min-height: 650px;
	}
	.slick-image-i {
		max-width: 100%;
		max-height: 100%;
	}
	.slick-dots {
		position: absolute;
		bottom: 30px;
		left: 0;
		right: 0;
		display: flex !important;
		justify-content: center;
		transform: none;
		margin: 0;
		padding: 0;
		list-style: none;
		li {
			margin-left: 7px;
			margin-right: 7px;
			button {
				padding: 0;
				border: none;
				font-size: 0;
				width: 10px;
				height: 10px;
				background: var(--webiny-cms-theme-text-primary);
				border-radius: 5px;
				transition: 0.2s background ease-in-out;
				cursor: pointer;
			}
			&.slick-active {
				button {
					background: var(--webiny-cms-theme-primary);
				}
			}
		}
	}
`;

export default Carousel;
