// @flow
import React from "react";
import type { ElementPluginType } from "webiny-app-cms/types";
import { Tab } from "webiny-ui/Tabs";
import styled from "react-emotion";

import { ReactComponent as DesignIcon } from "webiny-app-cms/editor/plugins/elements/imagesList/icons/round-style-24px.svg";
import { ReactComponent as CustomPreviewIcon } from "./assets/custom-group-preview.svg";
import {Cell, Grid} from "webiny-ui/Grid";
import SingleImageUpload from "webiny-admin/components/SingleImageUpload";
import {Image} from "webiny-ui/Image";
import {Input} from "webiny-ui/Input";

export default () => {
	const PreviewBox = styled("div")({
		textAlign: "center",
		margin: "0 auto",
		width: 50,
		svg: {
			width: 50
		}
	});

	return [
		({
			name: "cms-element-custom-image-hovered",
			type: "cms-element",
			toolbar: {
				title: "Image Split Hover",
				group: "cms-element-group-custom",
				preview() {
					return (
						<PreviewBox>
							<CustomPreviewIcon />
						</PreviewBox>
					);
				}
			},
			settings: ["cms-element-settings-delete"],
			target: ["cms-element-row", "cms-element-column"],
			onCreate: "open-settings",
			create(options = {}) {
				return {
					type: "cms-element-custom-image-hovered",
					data: {},
					...options
				};
			},
			render(props) {
				const { element: { data: { image = {} } } } = props;

				return <Image src={image.src} alt={image.name} />;
			}
		}: ElementPluginType),
		{
			name: "cms-element-advanced-settings-custom-image-hovered",
			type: "cms-element-advanced-settings",
			element: "cms-element-custom-image-hovered",
			render({ Bind }) {
				return (
					<Tab icon={<DesignIcon />} label="Options">
						<Grid>
							<Cell span={6}>
								<Bind name={"image"}>
									<SingleImageUpload label="image" />
								</Bind>
							</Cell>
							<Cell span={6}>
								<Bind name={"url"}>
									<Input placeholder="Enter url" />
								</Bind>
							</Cell>
						</Grid>
					</Tab>
				);
			}
		}
	];
};
