// @flow
import React from "react";
import type { ElementPluginType } from "webiny-app-cms/types";
import { Tab } from "webiny-ui/Tabs";
import styled from "react-emotion";

import { ReactComponent as DesignIcon } from "webiny-app-cms/editor/plugins/elements/imagesList/icons/round-style-24px.svg";
import {Cell, Grid} from "webiny-ui/Grid";
import SingleImageUpload from "webiny-admin/components/SingleImageUpload";
import {Input} from "webiny-ui/Input";
import CustomVideo from "../render/components/CustomVideo";

export default () => {
	const PreviewBox = styled("div")({
		textAlign: "center",
		margin: "0 auto",
		width: 50,
		svg: {
			width: 50
		}
	});

	return [
		({
			name: "cms-element-custom-video",
			type: "cms-element",
			toolbar: {
				title: "Custom video",
				group: "cms-element-group-custom",
				preview() {
					return (
						<PreviewBox>
							<svg width="50" height="35" viewBox="0 0 50 35" xmlns="http://www.w3.org/2000/svg"><path d="M50 0v35h-50v-35h50zm-36.791 2.3v30.4h23.679v-30.4h-23.679zm-2.348 30.4v-5.8h-8.513v5.8h8.513zm0-8.1v-5.9h-8.513v5.9h8.513zm0-8.3v-5.9h-8.513v5.9h8.513zm0-8.2v-5.8h-8.513v5.8h8.513zm28.376-5.8v5.8h8.415v-5.8h-8.415zm0 8.1v5.9h8.415v-5.9h-8.415zm0 8.3v5.9h8.415v-5.9h-8.415zm0 8.2v5.8h8.415v-5.8h-8.415zm-10.176-9.4c-2.446-1.4-4.697-2.8-7.045-4.1v8.1c2.25-1.3 4.599-2.6 7.045-4zm2.446 1.3c-3.229 1.9-6.458 3.7-9.589 5.6-1.076.6-2.153-.1-2.153-1.3v-11.2c0-1.2 1.174-1.9 2.153-1.3 3.131 1.9 6.36 3.7 9.589 5.6.881.6.881 2 0 2.6z" fill="#000" fill-rule="nonzero"/></svg>
						</PreviewBox>
					);
				}
			},
			settings: ["cms-element-settings-delete"],
			target: ["cms-element-row", "cms-element-column"],
			onCreate: "open-settings",
			create(options = {}) {
				return {
					type: "cms-element-custom-video",
					data: {},
					...options
				};
			},
			render(props) {
				return <CustomVideo {...props} />;
			}
		}: ElementPluginType),
		{
			name: "cms-element-advanced-settings-custom-video",
			type: "cms-element-advanced-settings",
			element: "cms-element-custom-video",
			render({ Bind }) {
				return (
					<Tab icon={<DesignIcon />} label="Options">
						<Grid>
							<Cell span={6}>
								<Bind name={"videoUrl"}>
									<Input placeholder="Enter video URL" />
								</Bind>
							</Cell>
						</Grid>
					</Tab>
				);
			}
		}
	];
};
