import { EntityModel } from "webiny-entity";
import { Model } from "webiny-model";

class FileModel extends Model {
    name: string;
    size: number;
    src: string;
    type: string;
    constructor() {
        super();
        this.attr("name").char();
        this.attr("size").integer();
        this.attr("src").char();
        this.attr("type").char();
    }
}

class AdditionalCustomFieldsModel extends EntityModel {
    constructor() {
        super();
        this.attr("property").char();
        this.attr("content").char();
    }
}

class AdditionalSettings extends EntityModel {
    constructor() {
        super();
        this.attr("fields").models(AdditionalCustomFieldsModel);
        this.attr("description").char();
        this.attr("image").model(FileModel);
    }
}

export default [
    {
        name: "cms-page-settings-additional",
        type: "cms-page-settings-model",
        apply({ model }: { model: EntityModel }) {
            model
                .attr("additional")
                .model(AdditionalSettings)
                .setDefaultValue({});
        }
    },
    {
        name: "cms-schema-settings-additional",
        type: "cms-schema",
        typeDefs: `
            type AdditionalCustomFields {
                property: String
                content: String
            }
            
            type AdditionalSettings {
                description: String
                fields: [AdditionalCustomFields]
                image: File
            } 
            
            extend type PageSettings {
                additional: AdditionalSettings
            }
        `
    }
];
