import React, { useState } from "react";
import { Link } from "react-router-dom";
import InfiniteScroll from 'react-infinite-scroller';

const ProjectsPageItem = ({ page }) => {
	const {
		settings: {
			general: {
				image
			}
		}
	} = page;

	return (
		<div className="works-list__item">
			<Link to={page.url} className="works-list__link">
				{
					image.src &&
					<div className="works-list__image">
						<img
							className="works-list__image-i"
							src={image.src}
							alt=""
						/>
					</div>
				}
				{
					page.title &&
					<div className="works-list__title">
						{page.title}
					</div>
				}
			</Link>
		</div>
	);
};

const ProjectsPageList = (props) => {
	const { data } = props;
	const SHOW_QUANTITY = 6;
	const [items, setItems] = useState(data.slice(0, SHOW_QUANTITY));
	const [hasMore, setHasMore] = useState(true);

	const loadFunc = () => {
		if (items.length < data.length) {
			setItems(data.slice(0, items.length + SHOW_QUANTITY));
		} else {
			setHasMore(false);
		}
	};

	return (
		<InfiniteScroll
			pageStart={0}
			loadMore={loadFunc}
			hasMore={hasMore}
			loader={<div className="content-loading" key={0}><div/><div/><div/></div>}
		>
			<div className="works-list">
				{items.map(page => (
					<ProjectsPageItem key={page.id} page={page} />
				))}
			</div>
		</InfiniteScroll>
	);
};

export default ProjectsPageList;
