import React from "react";
import loremIpsum from "lorem-ipsum";
import Text, { className } from "webiny-app-cms/editor/plugins/elements/text/Text";
import { createValue } from "webiny-app-cms/editor/components/Slate";
import type, { ElementPluginType } from "webiny-app-cms/types";
import { Tab } from "webiny-ui/Tabs";
import { Cell, Grid } from "webiny-ui/Grid";
import { Input } from "webiny-ui/Input";
import { Select } from "webiny-ui/Select";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { ReactComponent as DesignIcon } from "webiny-app-cms/editor/plugins/elements/imagesList/icons/round-style-24px.svg";

export default () => {
	const defaultLipsum = {
		count: 3,
		units: "sentences",
		sentenceLowerBound: 5,
		sentenceUpperBound: 15
	};

	return [
		({
			name: "cms-element-ticker",
			type: "cms-element",
			toolbar: {
				title: "Ticker",
				group: "cms-element-group-custom",
				preview() {
					return <div className={className}>Ticker text</div>;
				}
			},
			settings: [
				"cms-element-settings-background",
				"",
				"cms-element-settings-border",
				"cms-element-settings-shadow",
				"",
				"cms-element-settings-padding",
				"cms-element-settings-margin",
				"",
				"cms-element-settings-clone",
				"cms-element-settings-delete",
				""
			],
			target: ["cms-element-column", "cms-element-row", "cms-element-list-item"],
			create({ content = {}, ...options }: Object) {
				const previewText = content.text || loremIpsum(content.lipsum || defaultLipsum);

				return {
					type: "cms-element-ticker",
					elements: [],
					data: {
						text: createValue(previewText, content.typography || "paragraph"),
						settings: {
							margin: {
								mobile: { top: 0, left: 0, right: 0, bottom: 15 },
								desktop: { top: 0, left: 0, right: 0, bottom: 25 },
								advanced: true
							},
							padding: {
								desktop: { all: 0 },
								mobile: { all: 0 }
							}
						}
					},
					...options
				};
			},
			render({ element }: Object) {
				return <Text elementId={element.id} />;
			}
		}: ElementPluginType),
		{
			name: "cms-element-advanced-settings-ticker",
			type: "cms-element-advanced-settings",
			element: "cms-element-ticker",
			render({ Bind }) {
				return (
					<Tab icon={<DesignIcon />} label="Options">
						<Grid>
							<Cell span={6}>
								<Bind
									name={"speed"}
									defaultValue="5"
								>
									<Input placeholder="Speed" />
								</Bind>
							</Cell>
							<Cell span={6}>
								<Bind
									name={"direction"}
									defaultValue="toLeft"
								>
									<Select
										label={"Direction"}
									>
										<option key="toLeft" value="toLeft">
											toLeft
										</option>
										<option key="toRight" value="toRight">
											toRight
										</option>
									</Select>
								</Bind>
							</Cell>
						</Grid>
						<Grid>
							<Cell span={6}>
								<Bind
									name={"mode"}
									defaultValue="chain"
								>
									<Select
										label={"Mode"}
									>
										<option key="chain" value="chain">
											chain
										</option>
										<option key="await" value="await">
											await
										</option>
										<option key="smooth" value="smooth">
											smooth
										</option>
									</Select>
								</Bind>
							</Cell>
						</Grid>
					</Tab>
				);
			}
		},
	];
};
